// IDecision.aidl
package com.huawei.common.service;
import com.huawei.common.service.IDecisionCallback;
// Declare any non-default types here with import statements

interface IDecision {

    void executeEvent(in Map fact, IDecisionCallback callback);

    int insertBusinessData(in Map fact);

    int removeBusinessData(in String category, in String id);

    /**
     * 创建预测场景
     *
     * @param sceneName
     *        创建场景的名称
     * @param algorithm
     *        算法类型，"auto"表示自动优化
     * @param featureSchema
     *        特征描述,Map<String, String>类型
     *        @key: 特征名称
     *        @value: 该特征对应的类型，当前支持类型(boolean, int, long, float, double, string)
     *        支持基础特征自行选择，举例选择时间维度形如[("date.*", "*")]，若填null，则默认全选所有基础特征
     * @param extend
     *        扩展场景描述,Map<String, Object>类型，非必选
     *        @key: 配置项
     *        @value: 配置项对应取值
     * @return boolean
     *         是否创建成功
     */
    int register(String sceneName, int algorithm, in Map featureSchema, in Map extend);

    /**
     * 删除预测场景
     *
     * @param sceneName
     *        删除场景的名称
     * @return boolean
     *         是否删除成功
     */
    int unRegister(String sceneName);

    /**
     * 更新预测场景
     *
     * @param sceneName
     *        更新场景的名称
     * @param updateContent
     *        具体更新配置内容
     * @return boolean
     *         是否删除成功
     */
    int update(String sceneName, String updateContent);

    /**
     * 根据场景名称记录单条训练数据
     *
     * @param sceneName
     *        删除场景的名称
     * @param feature
     *        扩展特征，必须包含"_timestamp"字段，表达label发生的时间
     * @param label
     *        预测结果
     * @return boolean
     *         是否记录成功
     */
    int log(String sceneName, String feature, int label);

    /**
     * 根据场景名称记录训练多条数据
     *
     * @param sceneName
     *        删除场景的名称
     * @param features
     *        扩展特征集合，List<String>类型，每一个特征向量必须包含"_timestamp"字段，表达label发生的时间
     * @param labels
     *        标签集合，List<Integer>类型
     * @return boolean
     *         是否记录成功
     */
    int batchLog(String sceneName, in List features, in List labels);

    /**
     * 预测推断
     *
     * @param sceneName
     *        删除场景的名称
     * @param feature
     *        扩展特征，必须包含timestamp字段，表达label发生的时间
     * @return LinkedHashMap
     *         根据置信度排序的结果映射表
     */
    int infer(String sceneName, String feature, inout Map result);
}
